﻿function Create-ToastMsg {
	[CmdletBinding()]
	param([string]$ToastMessage)
	
$AppID = "Windows.SystemToast.Biogroup.Software"
$AppRegPath = "HKLM:\Software\Classes\AppUserModelId"
$RegPath = "$AppRegPath\$AppID"
 if (-NOT(Test-Path $RegPath)) {New-Item -Path $AppRegPath -Name $AppID -Force | Out-Null}
New-ItemProperty -Path $RegPath -Name DisplayName -Value "Programmes et fonctionnalités" -PropertyType String -Force | Out-Null
New-ItemProperty -Path $RegPath -Name IconUri -Value "%ProgramData%\BiogroupIT\Images\software.png" -PropertyType ExpandString -Force | Out-Null
New-ItemProperty -Path $RegPath -Name "ShowInActionCenter" -Value 1 -PropertyType "DWORD" -Force | Out-Null
New-ItemProperty -Path $RegPath -Name "Enabled" -Value 1 -PropertyType "DWORD" -Force | Out-Null

if ((Get-ItemProperty -Path $RegPath -Name "Enabled").Enabled -ne "1")  {
    New-ItemProperty -Path $RegPath -Name "Enabled" -Value 1 -PropertyType "DWORD" -Force | Out-Null
}

@" 
`$xml = @"
<toast scenario="reminder">
    <visual>
    <binding template="ToastGeneric">
		<image placement="hero" src="C:\ProgramData\BiogroupIT\Images\ToastHero.png"/>
        <image id="1" placement="appLogoOverride" src="C:\ProgramData\BiogroupIT\Images\ToastLogo.png"/>
        <text hint-style="Title">Biogroup</text>
        <text placement="attribution">Service IT</text>
        <group>
            <subgroup>
                <text hint-style="Base" hint-wrap="true">Installation logiciel</text>
            </subgroup>
        </group>
		<group>
            <subgroup>
				<text hint-style="body" hint-wrap="true">$ToastMessage</text>
            </subgroup>
        </group>
    </binding>
    </visual>
	<actions>
      <action content="OK" activationType="system" arguments="dismiss"/>
    </actions>
</toast>
"`@
	  
`$XmlDocument = [Windows.Data.Xml.Dom.XmlDocument, Windows.Data.Xml.Dom.XmlDocument, ContentType = WindowsRuntime]::New()
`$XmlDocument.loadXml(`$xml)
`$AppId = 'Windows.SystemToast.Biogroup.Software'
[Windows.UI.Notifications.ToastNotificationManager]::History.Clear(`$AppId)
[Windows.UI.Notifications.ToastNotificationManager, Windows.UI.Notifications, ContentType = WindowsRuntime]::CreateToastNotifier(`$AppID).Show(`$XmlDocument)

"@ | Out-File "C:\ProgramData\BiogroupIT\Staging\Toast_Message.ps1" -Encoding UTF8

$LogUser = (gwmi Win32_ComputerSystem).UserName
$action = New-ScheduledTaskAction -Execute "C:\Windows\System32\RunSilent.exe" -Argument "-File `"C:\ProgramData\BiogroupIT\Staging\Toast_Message.ps1`""
$trigger = New-ScheduledTaskTrigger -AtLogOn
$principal = New-ScheduledTaskPrincipal -UserId $LogUser
$task = New-ScheduledTask -Action $action -Trigger $trigger -Principal $principal
Register-ScheduledTask ToastMsg -InputObject $task
Start-ScheduledTask -TaskName ToastMsg
Unregister-ScheduledTask -TaskName ToastMsg -Confirm:$false

}

function Run-UserScript {
	[CmdletBinding()]
	param([string]$UserScript)
	
$LogUser = (gwmi Win32_ComputerSystem).UserName
$action = New-ScheduledTaskAction -Execute "C:\Windows\System32\RunSilent.exe" -Argument "-File $UserScript"
$trigger = New-ScheduledTaskTrigger -AtLogOn
$principal = New-ScheduledTaskPrincipal -UserId $LogUser
$task = New-ScheduledTask -Action $action -Trigger $trigger -Principal $principal
Register-ScheduledTask UserScript -InputObject $task
Start-ScheduledTask -TaskName UserScript
Unregister-ScheduledTask -TaskName UserScript -Confirm:$false

}

if (!(Test-Path "$($env:windir)\System32\RunSilent.exe")) {
$header = "ZG9scGhpbnZlbnRvcnk6TUlaOTVTM1BvbXdtMjBzQ0lCSVl5QlhXVGdPS3F4dUhtS3NWR0NVWW1QaGtoMnV6Vng2VUIwU3NaNCplWFJiUA=="
Start-Process "curl.exe" -Wait -NoNewWindow -ArgumentList "-s -H `"Authorization: Basic $header`" -O https://murloc.biogroup.network/arthas/sources/RunSilent.exe" -WorkingDirectory "$env:windir\System32"	
}

@"
if (!(Test-Path `$env:USERPROFILE\AppData\Local\CiscoSparkLauncher\CiscoCollabHost.exe)) {
Write-Output "NotInstalled" | Out-File -FilePath "`$env:ProgramData\BiogroupIT\Staging\NotInstalled.conf"
}
"@ | Out-File "C:\ProgramData\BiogroupIT\Staging\Detection.ps1" -Encoding UTF8
Run-UserScript -UserScript "C:\ProgramData\BiogroupIT\Staging\Detection.ps1"

Start-Sleep -s 3

if (Test-Path "$env:ProgramData\BiogroupIT\Staging\NotInstalled.conf") {

Create-ToastMsg -ToastMessage "Installation de Webex en cours..."

$header = "ZG9scGhpbnZlbnRvcnk6TUlaOTVTM1BvbXdtMjBzQ0lCSVl5QlhXVGdPS3F4dUhtS3NWR0NVWW1QaGtoMnV6Vng2VUIwU3NaNCplWFJiUA=="
Start-Process "curl.exe" -Wait -NoNewWindow -ArgumentList "-s -H `"Authorization: Basic $header`" -O https://murloc.biogroup.network/arthas/sources/Webex.msi" -WorkingDirectory "$env:ProgramData\BiogroupIT\Temp"

@"
Start-Process "msiexec" -Wait -ArgumentList "/i ``"`$env:ProgramData\BiogroupIT\Temp\webex.msi``" /qn"
Write-Output "Complete" | Out-File -FilePath "`$env:ProgramData\BiogroupIT\Staging\Complete.end"
"@ | Out-File "C:\ProgramData\BiogroupIT\Staging\Install_WebexUser.ps1" -Encoding UTF8
Run-UserScript -UserScript "C:\ProgramData\BiogroupIT\Staging\Install_WebexUser.ps1"

$path = "$env:ProgramData\BiogroupIT\Staging\Complete.end"
do { 
    if (-not (Test-Path $path)) {
        Start-Sleep -s 3
    }
} until (Test-Path $path)

Create-ToastMsg -ToastMessage "L'installation de Webex est terminée."

Start-Sleep -s 5

}

Remove-Item "$($env:ProgramData)\BiogroupIT\Images" -Recurse -Force
Remove-Item "$($env:ProgramData)\BiogroupIT\Staging" -Recurse -Force
Remove-Item "$($env:ProgramData)\BiogroupIT\Temp" -Recurse -Force
if (Test-Path "HKLM:\Software\Classes\AppUserModelId\Windows.SystemToast.Biogroup.Software") {Remove-Item "HKLM:\Software\Classes\AppUserModelId\Windows.SystemToast.Biogroup.Software" -Force | Out-Null}